# Generated by Django 5.0.14 on 2025-05-26 22:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0003_sepabranch_allow_test'),
    ]

    operations = [
        migrations.CreateModel(
            name='InterfacesPredefinidas',
            fields=[
                ('interfaz_id', models.IntegerField(unique=True)),
                ('renglon_id', models.IntegerField(blank=True, db_column='RenglonID', null=True)),
                ('interfaz', models.CharField(db_column='Interfaz', max_length=100, primary_key=True, serialize=False)),
                ('marca', models.CharField(db_column='Marca', max_length=50)),
                ('estatus', models.BooleanField(db_column='Estatus')),
                ('reenvio_rango', models.BooleanField(db_column='ReenvioRango')),
                ('abrir_mov', models.BooleanField(db_column='AbrirMov')),
                ('reenvio_multiple', models.BooleanField(db_column='ReenvioMultiple')),
                ('descripcion', models.CharField(blank=True, db_column='Descripcion', max_length=100, null=True)),
            ],
            options={
                'db_table': 'CA_InterfacesPredefinidas',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='InterfacesPredefinidasDEmpresa',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('renglon_id', models.IntegerField(blank=True, db_column='RenglonID', null=True)),
                ('clave', models.CharField(db_column='Clave', max_length=50)),
                ('descripcion', models.CharField(db_column='Descripcion', max_length=100)),
                ('valor_default', models.CharField(blank=True, db_column='ValorDefault', max_length=255, null=True)),
            ],
            options={
                'db_table': 'CA_InterfacesPredefinidasDEmpresa',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='ParametrosSucursal',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('empresa', models.CharField(db_column='Empresa', max_length=5)),
                ('sucursal', models.IntegerField(db_column='Sucursal')),
                ('clave', models.CharField(db_column='Clave', max_length=30)),
                ('descripcion', models.CharField(blank=True, db_column='Descripcion', max_length=200, null=True)),
                ('grupo', models.CharField(blank=True, db_column='Grupo', max_length=20, null=True)),
                ('valor', models.CharField(blank=True, db_column='Valor', max_length=100, null=True)),
            ],
            options={
                'db_table': 'CA_CatParametrosSucursal',
                'managed': False,
            },
        ),
    ]
