# Generated by Django 5.0.9 on 2025-04-24 14:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0002_artcosto_compra_listapreciosd_serielote_vinaccesorio_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='sepabranch',
            name='allow_test',
            field=models.BooleanField(default=False),
        ),
    ]
