# Generated by Django 5.0.9 on 2025-04-24 11:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ArtCosto',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('empresa', models.CharField(db_column='Empresa', max_length=5)),
                ('ultimo_costo', models.FloatField(blank=True, db_column='UltimoCosto', null=True)),
                ('costo_promedio', models.FloatField(blank=True, db_column='CostoPromedio', null=True)),
                ('costo_estandar', models.FloatField(blank=True, db_column='CostoEstandar', null=True)),
                ('costo_reposicion', models.FloatField(blank=True, db_column='CostoReposicion', null=True)),
                ('ultimo_costo_sin_gastos', models.FloatField(blank=True, db_column='UltimoCostoSinGastos', null=True)),
            ],
            options={
                'db_table': 'ArtCosto',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Compra',
            fields=[
                ('id', models.AutoField(db_column='ID', primary_key=True, serialize=False, unique=True)),
                ('importe', models.DecimalField(blank=True, db_column='Importe', decimal_places=4, max_digits=19, null=True)),
                ('impuestos', models.DecimalField(blank=True, db_column='Impuestos', decimal_places=4, max_digits=19, null=True)),
            ],
            options={
                'db_table': 'Compra',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='ListaPreciosD',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('lista', models.CharField(db_column='Lista', max_length=20)),
                ('moneda', models.CharField(db_column='Moneda', max_length=10)),
                ('precio', models.DecimalField(blank=True, db_column='Precio', decimal_places=4, max_digits=18, null=True)),
                ('codigo_cliente', models.CharField(blank=True, db_column='CodigoCliente', max_length=20, null=True)),
                ('margen', models.FloatField(blank=True, db_column='Margen', null=True)),
                ('region', models.CharField(blank=True, db_column='Region', max_length=50, null=True)),
            ],
            options={
                'db_table': 'ListaPreciosD',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='SerieLote',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('serie_lote', models.CharField(db_column='SerieLote', max_length=50)),
                ('existencia', models.FloatField(blank=True, db_column='Existencia', null=True)),
            ],
            options={
                'db_table': 'SerieLote',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='VinAccesorio',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('descripcion', models.CharField(blank=True, db_column='Descripcion', max_length=100, null=True)),
                ('precio_contado', models.DecimalField(blank=True, db_column='PrecioContado', decimal_places=4, max_digits=19, null=True)),
            ],
            options={
                'db_table': 'VinAccesorio',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='VinTipoAccesorio',
            fields=[
                ('tipo', models.CharField(db_column='Tipo', max_length=50, primary_key=True, serialize=False)),
                ('afecta_costo', models.BooleanField(db_column='AfectaCosto')),
                ('afecta_precio', models.BooleanField(db_column='AfectaPrecio')),
                ('afecta_gasto', models.BooleanField(db_column='AfectaGasto')),
            ],
            options={
                'db_table': 'VinTipoAccesorio',
                'managed': False,
            },
        ),
        migrations.AlterField(
            model_name='userapi',
            name='usuario',
            field=models.CharField(blank=True, db_column='usuario', max_length=254, unique=True),
        ),
        migrations.RenameField(
            model_name='userapi',
            old_name='usuario',
            new_name='username',
        ),
        migrations.RemoveField(
            model_name='sepabranch',
            name='foto',
        ),
        migrations.RemoveField(
            model_name='sepabranch',
            name='foto_alt',
        ),
        migrations.RemoveField(
            model_name='sepacompanies',
            name='foto',
        ),
        migrations.RemoveField(
            model_name='sepacompanies',
            name='foto_alt',
        ),
        migrations.RemoveField(
            model_name='userapi',
            name='foto',
        ),
        migrations.RemoveField(
            model_name='userapi',
            name='foto_alt',
        ),
    ]
